#!/home/user/anaconda3/bin/python
# -*- coding: utf-8 -*-

#-------------------------------------------------------------------------------

# This file is part of Code_Saturne, a general-purpose CFD tool.
#
# Copyright (C) 1998-2019 EDF S.A.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA 02110-1301, USA.

#-------------------------------------------------------------------------------

import os
import sys

#-------------------------------------------------------------------------------
# Handle Python modules possible locations
#-------------------------------------------------------------------------------

# Store the installation path of Code_Saturne Python modules.
cspath = '/usr/local/lib/python3.6/site-packages/code_saturne'

# Store the information whether the installation is relocatable or not.
relocatable = 'no'

# Get the script rootdir (especially useful for relocatable installation)
#   When frozen with cx_freeze __file__ is not defined in code_saturne,
#   therefore we use two different ways of getting the script path.
if hasattr(sys, 'frozen'):
    rootdir = sys.executable
else:
    rootdir = os.path.realpath(__file__)

# For a relocatable installation, reset cspath (i.e. for a standard Python
# installation: lib/pythonX.Y/site-packages/code_saturne). We also assume
# that the main script still lies in the bin directory.
if relocatable == 'yes':
    bindir = os.path.dirname(rootdir)
    prefix = os.path.dirname(bindir)
    sitedir = os.path.join(prefix,
                           'lib', 'python' + sys.version[:3], 'site-packages')
    cspath = os.path.join(sitedir, 'code_saturne')

#-------------------------------------------------------------------------------
# Main
#-------------------------------------------------------------------------------

if __name__ == '__main__':

    # Trick so that one doesn't have to set the PYTHONPATH variable
    if os.path.isdir(cspath) and not cspath in sys.path:
        sys.path.insert(0, cspath)

    from cs_script import master_script

    # Retrieve package information (name, version, installation dirs, ...)
    from cs_package import package
    pkg = package()

    # Create an instance of the main script
    cs = master_script(sys.argv[1:], pkg)

    retcode = cs.execute()

    if retcode == None:
        retcode = 0

    sys.exit(retcode)

#-------------------------------------------------------------------------------
# End
#-------------------------------------------------------------------------------
